# AFHS Descriptive Example

library(haven)
library(dplyr)
library(tidyr)
library(survey) 

# Reading female response data----
setwd("YOUR_DIRECTORY")
datF_wt <- read_sas("afhs_female_recoded.sas7bdat")

dim(datF_wt)

# Variable preparation ----

# Recode value 99998 (Does Not Apply) to NA to facilitate analysis
datF_wt <- replace(datF_wt, datF_wt == 99998, NA)
                   

# One variable from each module
table(datF_wt$SecFemA_ONOWN, exclude= F) # in module 1
## 
##    1    5 <NA> 
##  252 1102    3
table(datF_wt$SecFemF_MEDTST12, exclude= F) # in module 2
## 
##    1    5 <NA> 
##  404  868   85
table(datF_wt$SecFemJ_SMK100, exclude= F) # in module 3
## 
##    1    5 <NA> 
##  329  901  127

datF_wt$SecFemA_ONOWN<- (datF_wt$SecFemA_ONOWN==1)*1 
datF_wt$SecFemF_MEDTST12<- (datF_wt$SecFemF_MEDTST12==1)*1 
datF_wt$SecFemJ_SMK100<- (datF_wt$SecFemJ_SMK100==1)*1 


# Weighted estimates ----

## For variables in module 1 ----
# design
options(survey.lonely.psu="adjust") #http://r-survey.r-forge.r-project.org/survey/exmample-lonely.html
design <- svrepdesign(ids= ~0, # no clustering
                      data= datF_wt, 
                      #for variable in M1, use all cases
                      weight= ~PS_Wgt_Female1_trimmed,
                      repweights= "PS_Wgt_Female1_trimmed_BS_[1-9]", 
                      type= "bootstrap")

# Estimate
svymean(~SecFemA_ONOWN, design, na.rm= T)

## For variables in module 2 ----
# design
options(survey.lonely.psu="adjust") #http://r-survey.r-forge.r-project.org/survey/exmample-lonely.html
design<- svrepdesign(ids= ~0, # no clustering
                     data= datF_wt[!is.na(datF_wt$PS_Wgt_Female12_trimmed),], 
                     #for variable in M2, use cases that participated in M1 and M2
                     weight= ~PS_Wgt_Female12_trimmed,
                     repweights= "PS_Wgt_Female12_trimmed_BS_[1-9]",
                     #using survey weights named xxx12_xxx, for cases participated in M1 and M2
                     type= "bootstrap")

# Estimate
svymean(~SecFemF_MEDTST12, design, na.rm= T)
##                     mean     SE
## SecFemF_MEDTST12 0.29499 0.0142


## For variables in module 3 ----
# design
options(survey.lonely.psu="adjust") #http://r-survey.r-forge.r-project.org/survey/exmample-lonely.html
design<- svrepdesign(ids= ~0, # no clustering
                     data= datF_wt[!is.na(datF_wt$PS_Wgt_Female123_trimmed),], 
                     #for variable in M3, use cases that participated in M1, M2, and M3
                     weight= ~PS_Wgt_Female123_trimmed,
                     repweights= "PS_Wgt_Female123_trimmed_BS_[1-9]", 
                     #using survey weights named xxx123_xxx, for cases participated in M1, M2, and M3
                     type= "bootstrap")


# Estimate
svymean(~SecFemJ_SMK100, design, na.rm= T)
##                   mean     SE
## SecFemJ_SMK100 0.29952 0.0161



# Reading male response data----
setwd("YOUR_DIRECTORY")
datM_wt <- read_sas("afhs_male_recoded.sas7bdat")


# Variables preparation ----

# Recode value 99998 (Does Not Apply) to NA to facilitate analysis
datM_wt <- replace(datM_wt, datM_wt == 99998, NA)

# Example variables in different sections
# One variable in each module
table(datM_wt$SecMaleA_ONOWN, exclude= F)
## 
##   1   5 
## 189 800
table(datM_wt$SecMaleF_OTPREG, exclude= F)
## 
##    1    5 <NA> 
##  184  610  195
table(datM_wt$SecMaleK_SMK100, exclude= F)
## 
##    1    5 <NA> 
##  280  600  109


#recoding to 1/0 under the same variable name
datM_wt$SecMaleA_ONOWN<- (datM_wt$SecMaleA_ONOWN==1)*1 
datM_wt$SecMaleF_OTPREG<- (datM_wt$SecMaleF_OTPREG==1)*1 
datM_wt$SecMaleK_SMK100<- (datM_wt$SecMaleK_SMK100==1)*1 


# 4. Weighted estimates----

## For variables in module 1 ----
# design
options(survey.lonely.psu="adjust") #http://r-survey.r-forge.r-project.org/survey/exmample-lonely.html
design<- svrepdesign(ids= ~0, # no clustering
                     data= datM_wt, 
                     #for variable in M1, use all cases
                     weight= ~PS_Wgt_Male1_trimmed,
                     repweights= "PS_Wgt_Male1_trimmed_BS_[1-9]", 
                     type= "bootstrap")

# estimate
svymean(~SecMaleA_ONOWN, design, na.rm= T)
##                   mean     SE
## SecMaleA_ONOWN 0.19608 0.0153


## For variables in module 2 ----
# design
options(survey.lonely.psu="adjust") #http://r-survey.r-forge.r-project.org/survey/exmample-lonely.html
design<- svrepdesign(ids= ~0, # no clustering
                     data= datM_wt[!is.na(datM_wt$PS_Wgt_Male12_trimmed),], 
                     #for variable in M2, use cases that participated in M1 and M2
                     weight= ~PS_Wgt_Male12_trimmed,
                     repweights= "PS_Wgt_Male12_trimmed_BS_[1-9]", 
                     #using survey weights named xxx12_xxx, for cases participated in M1 and M2
                     type= "bootstrap")
# estimate
svymean(~SecMaleF_OTPREG, design, na.rm= T)
##                  mean     SE
## SecMaleF_OTPREG 0.238 0.0188


## For variables in module 3 ----
# design
options(survey.lonely.psu="adjust") #http://r-survey.r-forge.r-project.org/survey/exmample-lonely.html
design<- svrepdesign(ids= ~0, # no clustering
                     data= datM_wt[!is.na(datM_wt$PS_Wgt_Male123_trimmed),], 
                     #for variable in M3, use cases that participated in M1, M2, and M3
                     weight= ~PS_Wgt_Male123_trimmed,
                     repweights= "PS_Wgt_Male123_trimmed_BS_[1-9]", 
                     #using survey weights named xxx123_xxx, for cases participated in M1, M2, and M3
                     type= "bootstrap")

# Estimate
svymean(~SecMaleK_SMK100, design, na.rm= T)
##                    mean     SE
## SecMaleK_SMK100 0.34463 0.0183



